@@ -1,13 +1,13 @@
 package NewsExtractor::SiteSpecificExtractor::UDN;
 use utf8;
 use Moo;
-extends 'NewsExtractor::GenericExtractor';
+extends 'NewsExtractor::SiteSpecificExtractor';
 
-use Importer 'NewsExtractor::TextUtil' => qw( normalize_whitespace reformat_dateline );
+use Importer 'NewsExtractor::TextUtil' => qw( html2text normalize_whitespace reformat_dateline );
 
 sub headline {
     my ($self) = @_;
-    my $el = $self->dom->at('#story_art_title, h1.story_art_title') or return;
+    my $el = $self->dom->at('#story_art_title, h1.story_art_title, h1.article-content__title') or return;
     my $txt = $el->all_text;
     return normalize_whitespace($txt);
 }
@@ -15,7 +15,7 @@ sub headline {
 sub dateline {
     my ($self) = @_;
     my $el;
-    if ($el = $self->dom->at(".shareBar__info--author > span:nth-child(1)")) {
+    if ($el = $self->dom->at(".shareBar__info--author > span:nth-child(1), .authors time.article-content__time")) {
         my $txt = $el->all_text;
         return normalize_whitespace($txt);
     }
@@ -29,8 +29,10 @@ sub dateline {
 sub journalist {
     my ($self) = @_;
     my $el;
-    if ($el = $self->dom->at(".shareBar__info--author")) {
-        return normalize_whitespace($el->text);
+    if ($el = $self->dom->at(".shareBar__info--author, .authors span.article-content__author")) {
+        my $txt = $el->all_text;
+        $txt =~ s/\s+/ /g; # Sometimes there are newlines
+        return normalize_whitespace($txt);
     }
 
     # opinion.udn.com
@@ -39,4 +41,11 @@ sub journalist {
     }
 }
 
+sub content_text {
+    my ($self) = @_;
+    my $el = $self->dom->at("section.article-content__editor");
+    $el->find("script, style")->map("remove");
+    return html2text("$el");
+}
+
 1;
