@@ -3,20 +3,20 @@ use utf8;
 use Moo;
 extends 'NewsExtractor::SiteSpecificExtractor';
 
-use Importer 'NewsExtractor::TextUtil' => 'html2text';
+use Importer 'NewsExtractor::TextUtil' => ('html2text', 'normalize_whitespace', 'reformat_dateline');
 
 sub headline {
     my ($self) = @_;
     my $el = $self->dom->at('.news-detail-box > hgroup:nth-child(1) > h1:nth-child(1)');
-    return $el->all_text;
+    return normalize_whitespace( $el->all_text );
 }
 
 sub dateline {
     my ($self) = @_;
     my $el = $self->dom->at('.date');
-    my $txt = $el->all_text;
+    my $txt = normalize_whitespace( $el->all_text );
     $txt =~ s/^時間：//;
-    return $txt;
+    return reformat_dateline($txt, '+08:00');
 }
 
 sub journalist {
